Compute E-values (Equation 4 in Gilbert et al.) and controlled risk curve bias factor (Equation 6 in Gilbert et al.).
bias.factor(RRud, RReu)E.value(rr)
controlled.risk.bias.factor(ss, s.cent, s1, s2, RRud)
A vector of marker values
Central marker value
s1 and s2 are a pair of marker values for which we set a RRud.
controlled.risk.bias.factor returns a vector of bias factors corresponding to the vector of marker values in ss.
These three functions constitute an implementation of the core functionality in Gilbert et al. (2020). For examples on how to use these functions, see the code for Gilbert et al. at https://github.com/youyifong/CoPveryhighVE
Gilbert, Fong, Carone (2020) Assessment of Immune Correlates of Protection via Controlled Riskof Vaccine Recipients